@@ -174,6 +174,11 @@ chnames["}"] = _("right brace")
 #
 chnames["~"] = _("tilde")
 
+# Translators: this is the spoken character for the no break space
+# character (e.g., "&nbsp;" in HTML -- U+00a0)
+#
+chnames[u'\u00a0'] = _("no break space")
+
 # Translators: this is the spoken word for the character '¡' (U+00a1)
 #
 chnames[u'\u00a1'] = _("inverted exclamation point")
@@ -632,6 +637,14 @@ chnames[u'\u20ac'] = _("euro")
 #
 chnames[u'\u2122'] = _("trademark")
 
+# Translators: this is the spoken word for the character '←' (U+2190)
+#
+chnames[u'\u2190'] = _("left arrow")
+
+# Translators: this is the spoken word for the character '→' (U+2192)
+#
+chnames[u'\u2192'] = _("right arrow")
+
 # Translators: this is the spoken word for the character '≈' (U+2248)
 #
 chnames[u'\u2248'] = _("almost equal to")
